<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ast">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Desaniciar</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Poner a pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished">Aniciar una presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Copiar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Voltiar a la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Voltiar a la esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished">Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished">Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished">Información de la semeya</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="unfinished">Restaurar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Ensin_nome</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Crear</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Álbum nuevu</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>¿De xuru que quies desaniciar esti álbum?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Papelera</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importación</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Papelera</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>O arrastra semeyes hasta equí</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Importar too</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importar a:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Discu del sistema</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galería</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>El discu ta ocupáu y nun pue estrayese</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acuerdu</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Inorar</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Trocar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esportación</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Semeyes</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Descargues</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritoriu</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Guardar en:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formatu:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Calidá:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Esbillar otru direutoriu</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acuerdu</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>El nome del ficheru nun pue tar baleru</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>yá esiste. ¿Quies trocar el ficheru?</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>Unidá de %1</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Discu virxe de %1</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>Volume cifráu de %1</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>Volume de %1</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Esportación de semeyes</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Desaniciando…</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Restaurando…</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation>¿De xuru que quies desaniciar esta semeya del álbum?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Información básica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importación</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Aniciar una presentación</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esportar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Preseos</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galería</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbumes</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Semeyes</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Poner a pantalla completa</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Aniciar una presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a la esquierda</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de Favoritos</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Renomar un álbum</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Quitóse l&apos;álbum «%1»</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Amestóse con ésitu a «%1»</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>La importación tuvo ésitu</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>La importación falló</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>La esportación falló</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>La esportación tuvo ésitu</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Toles semeyes</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Llinia temporal</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbumes</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Colar d&apos;una presentación/pantalla completa</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar los atayos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Esbillar too</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Averar</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Alloñar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Avanzar una páxina</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Retroceder una páxina</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importando…</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Desaniciar</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Flax</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipu</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamañu del ficheru</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificación</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mou d&apos;esposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa d&apos;esposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tiempu d&apos;esposición</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Llonxitú focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura máxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mou de midida</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación del flax</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modelu de la cámara</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelu de la lente</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaciu de colores</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Discu del sistema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Esbillar</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Deseleicionar</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importóse&apos;l</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4.</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Semeyes</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a la esquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a la derecha</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Importando…</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nun hai resultaos</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Aniciar una presentación</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Resultaos de la busca</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Poner a pantalla completa</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Esportar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Amestar a Favoritos</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Quitar de Favoritos</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a la derecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a la esquierda</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Aniciar una presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Información de la semeya</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Amestar al álbum</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Quitar del álbum</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"> díes</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Información básica</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Data de modificación</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tipu</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Tamañu del ficheru</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Data de captura</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
